unit FormMain;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, ExtCtrls,
  Grids, StdCtrls, Buttons, Arrow;

type

  TContent = (Empty, Mine, Damsel, Target);

  { TMainForm }

  TMainForm = class(TForm)
    ArrowGoLeft: TArrow;
    ArrowGoUp: TArrow;
    ArrowGoRight: TArrow;
    ArrowGoDown: TArrow;
    ButtonNewGame: TButton;
    ButtonExit: TButton;
    ControlPanel: TPanel;
    Pictures: TImageList;
    Pitch: TDrawGrid;
    MinesLabel: TLabel;
    PointsLabel: TLabel;
    PointsTitleLabel: TLabel;
    MinesTitleLabel: TLabel;
    LevelLabel: TLabel;
    LevelTitleLable: TLabel;
    HeadingStaticText: TStaticText;
    procedure ArrowGoUpClick(Sender: TObject);
    procedure ButtonExitClick(Sender: TObject);
    procedure ButtonNewGameClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure InitializePitch(NumberOfMines : Integer);
    procedure PitchDrawCell(Sender: TObject; aCol, aRow: Integer; aRect: TRect;
      aState: TGridDrawState);
    procedure PitchMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
  private
    { private declarations }
    FPlayer : TBitmap;
    FMine : TBitmap;
    FTarget : TBitmap;
    FPitchContent : array of array of TContent;
  public
    { public declarations }
  end;


var
  MainForm: TMainForm;

  FLevel : Integer;

implementation

{$R *.lfm}

{ TMainForm }

procedure TMainForm.FormCreate(Sender: TObject);
begin
  SetLength(FPitchContent, Pitch.ColCount, Pitch.RowCount);
  FPlayer := TBitmap.Create;
  FTarget := TBitmap.Create;
  FMine := TBitmap.Create;
  Pictures.GetBitmap(0,FPlayer);
  Pictures.GetBitmap(1,FTarget);
  Pictures.GetBitmap(2, FMine);
  ButtonNewGameClick(self);
end;

procedure TMainForm.FormDestroy(Sender: TObject);
begin
  FPlayer.Free;
  FTarget.Free;
  FMine.Free;
  Pictures.Free;
end;

procedure TMainForm.InitializePitch(NumberOfMines: Integer);
var
  i, j : Integer;
  X, Y : Integer;
begin
  {Clear FPitchContent}
  for i := 0 to Pitch.ColCount-1 do
    for j := 1 to Pitch.RowCount-1 do
      FPitchContent[i, j] := Empty;
  Pitch.Invalidate;
  { Define Playerposition}
  Pitch.Col:= Pitch.ColCount div 2;
  Pitch.Row:= Pitch.RowCount-1;

  { Define Targetposition}
  for i := ((Pitch.ColCount div 2)-2) to ((Pitch.ColCount div 2)+2) do
    begin
      FPitchContent[i, 0] := Target;
    end;
  { Mining}
  Randomize;
  while NumberOfMines > 0 do
    begin
      X := Random(Pitch.ColCount);
      Y := Random(Pitch.RowCount);
      { No Mines in the first and last row!}
      if (Y > 0) and (Y < Pitch.RowCount-1) then
        begin
          {put down mine, if it is an empty place}
          if FPitchContent[X, Y] = Empty then
            begin
              FPitchContent[X, Y] := Mine;
              Pitch.Canvas.Draw(X, Y, FMine);
              Dec(NumberOfMines);
            end;
        end;
    end;

end;

procedure TMainForm.PitchDrawCell(Sender: TObject; aCol, aRow: Integer;
  aRect: TRect; aState: TGridDrawState);
begin
  if (aCol = Pitch.Col) and (aRow = Pitch.Row) then
    Pitch.Canvas.Draw(aRect.Left, aRect.Top, FPlayer)
  else if FPitchContent[aCol, aRow] = Mine then
    Pitch.Canvas.Draw(aRect.Left, aRect.Top,FMine);
end;

procedure TMainForm.PitchMouseDown(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  Abort;
end;

procedure TMainForm.ArrowGoUpClick(Sender: TObject);
begin

end;

procedure TMainForm.ButtonExitClick(Sender: TObject);
begin
  Close;
end;

procedure TMainForm.ButtonNewGameClick(Sender: TObject);
begin
  InitializePitch(80);
  Pitch.SetFocus;
end;

end.

